Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: ui/base/native_theme/native_theme_android.h

Issue 10447053: Converts remainder of ui and chrome/browser/ui/views/frame to use ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sorted headers in modified files Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/native_theme/native_theme_android.h
diff --git a/ui/base/native_theme/native_theme_android.h b/ui/base/native_theme/native_theme_android.h
index eba1f5f46ca683d7f000a701b8dff5806b86f5b1..04c7be305411b046583e199fc2796013e342600a 100644
--- a/ui/base/native_theme/native_theme_android.h
+++ b/ui/base/native_theme/native_theme_android.h
@@ -12,6 +12,7 @@
#include "ui/base/native_theme/native_theme.h"
namespace gfx {
+class ImageSkia;
class Rect;
class Size;
}
@@ -112,10 +113,10 @@ class NativeThemeAndroid : public NativeTheme {
int w,
int h) const;
// Draw the dest rectangle with the given bitmap which might be scaled if its
// size is not same as target rectangle.
void DrawBitmapInt(SkCanvas* canvas,
- const SkBitmap& bitmap,
+ const gfx::ImageSkia& image,
int src_x,
int src_y,
int src_w,
@@ -128,7 +129,7 @@ class NativeThemeAndroid : public NativeTheme {
// Draw the target rectangle with the |bitmap| accroding the given
// |tile_scale_x| and |tile_scale_y|
void DrawTiledImage(SkCanvas* canvas,
- const SkBitmap& bitmap,
+ const gfx::ImageSkia& image,
int src_x,
int src_y,
float tile_scale_x,
@@ -112,10 +113,10 @@ class NativeThemeAndroid : public NativeTheme {
int w,
int h) const;
- // Draw the dest rectangle with the given bitmap which might be scaled if its
+ // Draw the dest rectangle with the given image which might be scaled if its
// size is not same as target rectangle.
void DrawBitmapInt(SkCanvas* canvas,

Powered by Google App Engine
This is Rietveld 408576698